@@ -90,7 +90,7 @@ if (PEAR::isError($rc)) {
                     $log->err(logformat("Password is weark: $errmsg"));
                 } else {
                     $log->err(logformat("Changing password succeeded but password is weak: $errmsg"));
-                    $message = USS_NML_001."<br>($message)";
+                    $message = USS_NML_001."<br><font color=\"red\">Warning: $message</font>";
                 }
                 break;
               case AUTO_LOGIN_MIN_PASSWD:
@@ -138,7 +138,11 @@ $smarty->assign('winpasswd', $winpasswd);
 $smarty->assign('setoldpasswd', $setoldpasswd);
 $smarty->assign('uri', $_SERVER['SCRIPT_NAME'].'?app=password');
 if (isset($_GET['back'])) {
-    $smarty->assign('back', urldecode($_GET['back']));
+    $back = $_GET['back'];
+    if (preg_match('#^https?://[^/]+'.$_SERVER{'SCRIPT_NAME'}.'#', $back)) {
+        $back = '/pub/login.cgi?back='.urlencode($back);
+    }
+    $smarty->assign('back', $back);
 }
 if (file_exists('../lib/menu.php') && isset($conf['autologin'])) {
     $smarty->assign('use_menu', 1);
